@@ -59,14 +59,16 @@ test_that("z-curve EM can be fitted and reproduces OSC results", {
     ))
   
   # plot
-  expect_doppelganger("z-curve EM", function()plot(fit.EM, main = "OSC (with EM)", annotation = TRUE, CI = TRUE))
-  expect_doppelganger("z-curve EM (ggplot)", suppressWarnings(plot(fit.EM, main = "OSC (with EM)", annotation = TRUE, CI = TRUE, plot_type = "ggplot")))
+  skip_on_os("mac")
+  vdiffr::expect_doppelganger("z-curve EM", function()plot(fit.EM, main = "OSC (with EM)", annotation = TRUE, CI = TRUE))
+  vdiffr::expect_doppelganger("z-curve EM (ggplot)", suppressWarnings(plot(fit.EM, main = "OSC (with EM)", annotation = TRUE, CI = TRUE, plot_type = "ggplot")))
 
 })
 test_that("z-curve KD2 can be fitted and reproduces OSC results", {
-  
+
   # set seed for reproducibility 
   set.seed(666)
+  skip_on_os("mac")
   
   # fit the EM method
   fit.KD2 <- zcurve(OSC.z, method = "density", bootstrap = 10)
@@ -79,7 +81,7 @@ test_that("z-curve KD2 can be fitted and reproduces OSC results", {
       ""                                                       ,
       "Estimates:"                                             ,
       "      ERR       EDR "                                   ,
-      "0.6133950 0.5064392 "    
+      "0.6133975 0.5064694 "    
     ))
   
   # basic summary
@@ -94,14 +96,14 @@ test_that("z-curve KD2 can be fitted and reproduces OSC results", {
       "ERR    0.613 0.496 0.745"                                                                ,
       "EDR    0.506 0.141 0.714"                                                                ,
       ""                                                                                        ,
-      "Model converged in 47 iterations"                                                        ,
+      "Model converged in 46 iterations"                                                        ,
       "Fitted using 73 z-values. 90 supplied, 85 significant (ODR = 0.94, 95% CI [0.87, 0.98]).",
       "RMSE = 0.11, 95% CI[0.09, 0.19]"
     ))
   
   # plot
-  expect_doppelganger("z-curve KD2", function()plot(fit.KD2))
-  expect_doppelganger("z-curve KD2 (ggplot)", plot(fit.KD2, plot_type = "ggplot"))
+  vdiffr::expect_doppelganger("z-curve KD2", function()plot(fit.KD2))
+  vdiffr::expect_doppelganger("z-curve KD2 (ggplot)", plot(fit.KD2, plot_type = "ggplot"))
   
 })
 test_that("z-curve EM censoring works", {
@@ -132,8 +134,8 @@ test_that("z-curve EM censoring works", {
     ))
   
   # plot
-  expect_doppelganger("z-curve mixed EM", function()plot(fit.mixed, CI = TRUE))
-  expect_doppelganger("z-curve mixed EM (ggplot)", plot(fit.mixed, CI = TRUE, plot_type = "ggplot"))
+  vdiffr::expect_doppelganger("z-curve mixed EM", function()plot(fit.mixed, CI = TRUE))
+  vdiffr::expect_doppelganger("z-curve mixed EM (ggplot)", plot(fit.mixed, CI = TRUE, plot_type = "ggplot"))
   
   
   # censoring only
@@ -157,8 +159,8 @@ test_that("z-curve EM censoring works", {
     ))
   
   # plot
-  expect_doppelganger("z-curve cens EM", function()plot(fit.cens, CI = TRUE))
-  expect_doppelganger("z-curve cens EM (ggplot)", plot(fit.cens, CI = TRUE, plot_type = "ggplot"))
+  vdiffr::expect_doppelganger("z-curve cens EM", function()plot(fit.cens, CI = TRUE))
+  vdiffr::expect_doppelganger("z-curve cens EM (ggplot)", plot(fit.cens, CI = TRUE, plot_type = "ggplot"))
 })
 test_that("z-curve clustered works", {
   
@@ -204,7 +206,7 @@ test_that("z-curve clustered works", {
       "Q = -238.11, 95% CI[-269.95, -219.12]"  
     ))
   
-  expect_doppelganger("z-curve clustered rounded", function(){
+  vdiffr::expect_doppelganger("z-curve clustered rounded", function(){
     oldpar <- graphics::par(no.readonly = TRUE)
     on.exit(graphics::par(mfrow = oldpar[["mfrow"]]))
     par(mfrow = c(1, 2))
@@ -251,7 +253,7 @@ test_that("z-curve clustered works", {
       "Q = -201.69, 95% CI[-219.18, -185.82]" 
     ))
   
-  expect_doppelganger("z-curve clustered precise", function(){
+  vdiffr::expect_doppelganger("z-curve clustered precise", function(){
     oldpar <- graphics::par(no.readonly = TRUE)
     on.exit(graphics::par(mfrow = oldpar[["mfrow"]]))
     par(mfrow = c(1, 2))
@@ -298,7 +300,7 @@ test_that("z-curve clustered works", {
       "Q = -321.39, 95% CI[-361.78, -298.20]"  
     ))
   
-  expect_doppelganger("z-curve clustered mixed", function(){
+  vdiffr::expect_doppelganger("z-curve clustered mixed", function(){
     oldpar <- graphics::par(no.readonly = TRUE)
     on.exit(graphics::par(mfrow = oldpar[["mfrow"]]))
     par(mfrow = c(1, 2))
@@ -306,6 +308,6 @@ test_that("z-curve clustered works", {
     plot(fitw)
   })
   
-  expect_doppelganger("z-curve clustered mixed (ggplot-1)", plot(fitb, plot_type = "ggplot"))
-  expect_doppelganger("z-curve clustered mixed (ggplot-2)", plot(fitw, plot_type = "ggplot"))
+  vdiffr::expect_doppelganger("z-curve clustered mixed (ggplot-1)", plot(fitb, plot_type = "ggplot"))
+  vdiffr::expect_doppelganger("z-curve clustered mixed (ggplot-2)", plot(fitw, plot_type = "ggplot"))
 })
\ No newline at end of file
